/**
 * Copyright (c) 2020, MindFusion LLC - Bulgaria.
 */

import java.awt.BorderLayout;
import java.awt.event.MouseEvent;
import java.util.EnumSet;

import javax.swing.JFrame;
import javax.swing.JOptionPane;
import javax.swing.SwingUtilities;

import com.mindfusion.common.DateTime;
import com.mindfusion.common.DayOfWeek;
import com.mindfusion.drawing.Brushes;
import com.mindfusion.scheduling.Calendar;
import com.mindfusion.scheduling.CalendarAdapter;
import com.mindfusion.scheduling.CalendarDrawEvent;
import com.mindfusion.scheduling.CalendarView;
import com.mindfusion.scheduling.DateChangedEvent;
import com.mindfusion.scheduling.ItemModifiedEvent;
import com.mindfusion.scheduling.ItemMouseEvent;
import com.mindfusion.scheduling.ThemeType;
import com.mindfusion.scheduling.model.Appointment;
import com.mindfusion.scheduling.model.Item;
import com.mindfusion.scheduling.model.ItemEvent;
import com.mindfusion.scheduling.model.Recurrence;
import com.mindfusion.scheduling.model.RecurrenceEnd;
import com.mindfusion.scheduling.model.RecurrencePattern;
import com.mindfusion.scheduling.model.RecurrenceState;


public class MainWindow extends JFrame
{
	public static void main(String[] args)
	{
		SwingUtilities.invokeLater(new Runnable()
		{
			public void run()
			{
				try
				{
					new MainWindow().setVisible(true);
				}
				catch (Exception exp)
				{
				}
			}
		});
	}

	protected MainWindow()
	{
		setDefaultCloseOperation(EXIT_ON_CLOSE);
		setSize(400, 400);
		setTitle("Tutorial 1");

		calendar = new Calendar();
		getContentPane().add(calendar, BorderLayout.CENTER);

		initialDate = DateTime.now();
		calendar.beginInit();
		
		
		calendar.setCurrentView(CalendarView.SingleMonth);
		calendar.setTheme(ThemeType.Silver);
		calendar.getTimetableSettings().setShowNavigationButtons(true);
		calendar.getTimetableSettings().setShowDayHeader(true);
		calendar.getTimetableSettings().setVisibleColumns(3);
		calendar.getTimetableSettings().getDates().clear();
		calendar.getTimetableSettings().setStartTime(480);
		for (int i = 0; i < 5; i++)
		    calendar.getTimetableSettings().getDates().add(DateTime.today().addDays(i));
		
		
		Appointment app = new Appointment();
		app.setHeaderText("Piano");
		app.setDescriptionText("music classes");
		app.setStartTime(new DateTime(2020, 5, 30, 14, 0, 0));
		app.setEndTime(new DateTime(2020, 5, 30, 16, 30, 0));
		//calendar.getSchedule().getItems().add(app);

		Recurrence rec = new Recurrence();
		rec.setPattern(RecurrencePattern.Weekly);
		rec.setDaysOfWeek(EnumSet.of(DayOfWeek.Saturday, DayOfWeek.Tuesday, DayOfWeek.Thursday));	
		rec.setWeeks(1);
		rec.setStartDate(DateTime.today());
		rec.setRecurrenceEnd(RecurrenceEnd.Never);
		app.setRecurrence(rec);
		
		calendar.addCalendarListener(new CalendarAdapter(){
			public void itemModified (ItemModifiedEvent  e) {
				onItemModified(e);
			}
			
			@Override()
			public void visibleDateChanged(DateChangedEvent e) {
				onVisibleDateChanged(e);
			}
			
		});
		
		calendar.endInit();
	}
	
	//make sure that dates are rendered till the end of May
		public void onVisibleDateChanged(DateChangedEvent e)
		{
						
			if(e.getNewDate().getMonth() == initialDate.getMonth() + 4)
			{		
				calendar.setDate(new DateTime(initialDate.getYear(), 
						initialDate.getMonth() + 3, initialDate.getDay()));
			}
		}
	
	   
	protected void onItemModified(ItemModifiedEvent e)
	{
		Item master = null;
		
		if( e.getItem().getRecurrenceState() != RecurrenceState.Master)
			master = e.getItem().getRecurrence().getMaster();
		
		if(master != null)
		{
			DateTime newStart = e.getItem().getStartTime();
			DateTime newEnd = e.getItem().getEndTime();
			
			DateTime start = master.getStartTime();
			DateTime end = master.getEndTime();
					
			master.setStartTime(new DateTime(start.getYear(), start.getMonth(), start.getDay(), 
							newStart.getHour(), newStart.getMinute(), newStart.getSecond()));
			
			master.setEndTime(new DateTime(end.getYear(), end.getMonth(), end.getDay(), 
					newEnd.getHour(), newEnd.getMinute(), newEnd.getSecond()));
			
			master.getRecurrence().clearExceptions();
			
			
			}				
		
	}
	
	
	



	private static final long serialVersionUID = 1L;

	private Calendar calendar;
	private DateTime initialDate;
}